@@ -1,6 +1,6 @@
 # -*- coding: utf8 -*-
 # python >= 3.5
-# python3 en supprimant import typing et math.inf
+# python3 en supprimant import typing
 
 """ Outils pédagogiques pour l'étude des systèmes du 2ème ordre
 
@@ -118,12 +118,13 @@ les diagrammes de Bode")
 warnings.simplefilter('default', UserWarning)
 
 """ historique des versions
+0.3.9 : pep8 style
 0.3.8 : add warnings 2022-01
 0.3.7 : 2022-01
 0.0.1 : initial release 2021-11
 """
 
-__version__ = (0, 3, 8)
+__version__ = (0, 3, 9)
 __author__ = "Fabrice Sincère <fabrice.sincere@ac-grenoble.fr>"
 
 
@@ -159,7 +160,8 @@ w0 : pulsation propre (en rad/s)
         # amplification statique
         self.__A = A
         # fonction de transfert complexe (module acelectricity)
-        self.__fonction_transfert = acelectricity.Ratio(fw=lambda w: A/(1+2*coeff_amortissement*1j*w/w0-(w/w0)**2))
+        self.__fonction_transfert = acelectricity.Ratio(
+            fw=lambda w: A/(1+2*coeff_amortissement*1j*w/w0-(w/w0)**2))
 
     @property
     def pulsation_propre(self) -> float:
@@ -245,7 +247,6 @@ Exemple :
 >>> print(syst.gain_statique())
 20.0
 """
-        # getter
         return 20*math.log10(abs(self.__A))
 
     def frequence_propre(self) -> float:
@@ -356,7 +357,8 @@ Exemple :
             # régime apériodique
             m0 = math.sqrt(m*m-1)
             # réponse indicielle unitaire
-            return A*(1-(0.5/m0)*(math.exp(-w0*(m-m0)*t)/(m-m0)-math.exp(-w0*(m+m0)*t)/(m+m0)))
+            return (A*(1-(0.5/m0)*(math.exp(-w0*(m-m0)*t)/(m-m0)
+                    - math.exp(-w0*(m+m0)*t)/(m+m0))))
 
     def courbe_reponse_indicielle(self, tmin=None, tmax=None):
         """ Dessine la courbe de la réponse indicielle unitaire \
@@ -415,7 +417,8 @@ Exemple :
 >>> print(syst.frequence_resonance_harmonique())
 1550.27045...
 """
-        return self.abaque_frequence_resonance_harmonique(self.__coeff_amortissement, self.__w0)
+        return self.abaque_frequence_resonance_harmonique(
+            self.__coeff_amortissement, self.__w0)
 
     def facteur_resonance_harmonique(self) -> tuple:
         """ En régime harmonique, retourne le facteur de résonance \
@@ -430,7 +433,8 @@ Exemple :
 (*syst.facteur_resonance_harmonique()))
 facteur de résonance : 10.0125234864... ou 20.010870956... dB
 """
-        return self.abaque_facteur_resonance_harmonique(self.__coeff_amortissement)
+        return self.abaque_facteur_resonance_harmonique(
+            self.__coeff_amortissement)
 
     def fonction_transfert_complexe(self, valeur: float,
                                     unite: str = 'Hz') -> float:
@@ -522,7 +526,8 @@ Exemple :
 >>> print(syst.frequence_coupure_harmonique())
 2427.97905105...
 """
-        return self.abaque_frequence_coupure_harmonique(self.__coeff_amortissement, self.__w0)
+        return self.abaque_frequence_coupure_harmonique(
+            self.__coeff_amortissement, self.__w0)
 
     @staticmethod
     def abaque_frequence_coupure_harmonique(coeff_amortissement: float,
@@ -542,17 +547,17 @@ coeff_amortissement=0.16, w0=10000))
         if w0 <= 0:
             raise ValueError("La pulsation propre doit être positive")
         if m <= 100:
-            # valeur théorique
+            # formule théorique
             return w0/(2*math.pi)*math.sqrt(1-2*m*m+math.sqrt((2*m*m-1)**2+1))
         else:
             # approximation (car la précision de la formule
             # théorique se dégrade quand m augmente)
-            # développement limité
             warnings.warn('Valeur approchée avec une bonne approximation')
             return w0/(2*math.pi)/math.sqrt(2*(2*m*m-1))
 
     @staticmethod
-    def abaque_coeff_amortissement_harmonique(facteur_resonance_db: float) -> float:
+    def abaque_coeff_amortissement_harmonique(
+            facteur_resonance_db: float) -> float:
         """ En régime harmonique, retourne le coefficient \
 d'amortissement à partir du facteur de résonance en dB
 
@@ -565,28 +570,23 @@ facteur_resonance_db=20))
         if facteur_resonance_db <= 0:
             raise ValueError("Valeur positive attendue")
 
-        if facteur_resonance_db > 1000:
-            # TODO :
-            # développement limité
-            warnings.warn('Valeur attendue très proche de 0')
-            return 0.0
+        if facteur_resonance_db > 100:
+            # approximation
+            try:
+                f = 10**(facteur_resonance_db/20)
+            except OverflowError:
+                warnings.warn('Valeur attendue très proche de 0')
+                return 0.0
+            warnings.warn('Valeur approchée avec une bonne approximation')
+            return 1/(2*f)
 
-        # résolution à partir de la fonction inverse
-        # !calcul aberrant quand facteur_resonance_db > 1000 :
-        # on obtient 0.707 au lieu de 0!
-        # def facteur_resonance(coeff_amortissement):
-        #    m = coeff_amortissement
-        #    f = 1/(2*m*math.sqrt(1-m*m))
-        #    return 20*math.log10(f)
-        # return _rechercheSolution(1e-300, 2**-0.5, facteur_resonance_db, 1e-9,
-        # facteur_resonance)
-
-        # calcul exact
+        # formule théorique
         f = 10**(facteur_resonance_db/20)
         return math.sqrt((1-math.sqrt(1-1/f**2))/2)
 
     @staticmethod
-    def abaque_facteur_resonance_harmonique(coeff_amortissement: float) -> tuple:
+    def abaque_facteur_resonance_harmonique(
+            coeff_amortissement: float) -> tuple:
         """ En régime harmonique, retourne le facteur de résonance \
 sans unité et en dB (tuple)
 Retourne 1 et 0 dB si le coefficient d'amortissement est >= 1/√2 \
@@ -604,7 +604,7 @@ facteur de résonance : 10.0125234864... ou 20.010870956... dB
             raise ValueError("Le coefficient d'amortissement doit être positif")
         if m == 0:
             warnings.warn('Résonance infinie')
-            return math.inf, math.inf  # python >= 3.5
+            return float('inf'), float('inf')
         elif m >= 1/math.sqrt(2):
             # pas de résonance harmonique
             warnings.warn('Pas de résonance')
@@ -614,7 +614,8 @@ facteur de résonance : 10.0125234864... ou 20.010870956... dB
             return f, 20*math.log10(f)
 
     @staticmethod
-    def abaque_pulsation_propre_resonance_harmonique(coeff_amortissement: float, frequence_resonance: float) -> float:
+    def abaque_pulsation_propre_resonance_harmonique(
+            coeff_amortissement: float, frequence_resonance: float) -> float:
         """ En régime harmonique, retourne la pulsation propre \
 (en rad/s)
 Retourne 0 si le coefficient d'amortissement est >= 1/√2 \
@@ -641,7 +642,8 @@ coeff_amortissement=0.16, frequence_resonance=1550.27))
             return fr*(2*math.pi)/math.sqrt(1-2*m*m)
 
     @staticmethod
-    def abaque_frequence_resonance_harmonique(coeff_amortissement: float, w0: float) -> float:
+    def abaque_frequence_resonance_harmonique(
+            coeff_amortissement: float, w0: float) -> float:
         """ En régime harmonique, retourne la fréquence de résonance \
 (en hertz)
 Retourne 0 si le coefficient d'amortissement est >= 1/√2 \
@@ -687,20 +689,17 @@ positif")
             raise ValueError("La pulsation propre doit être positive")
         # pourcentage
         p = pourcentage*0.01
-        if p == 0:
-            # infini
-            warnings.warn('Temps de réponse infini')
-            return math.inf  # python >= 3.5
-        elif p == 1:
-            return 0
-        elif not(0 <= p <= 1):
+
+        if not(0.000001 <= p <= 1):
             raise ValueError("Le pourcentage doit être compris \
-entre 0 et 100 %")
+entre 0.0001 % et 100 %")
+        if p == 1:  # 100 %
+            return 0
 
         if m == 0:
             # régime oscillant
             warnings.warn('Temps de réponse infini')
-            return math.inf  # python >= 3.5
+            return float('inf')
         elif 0 < m < 1:
             # régime pseudo-périodique
             m0 = math.sqrt(1-m*m)
@@ -715,6 +714,9 @@ entre 0 et 100 %")
             n = 1
             while not 1-p < u(n*math.pi/(w0*m0)) < 1+p:
                 n += 1
+                if n > 10000:
+                    raise ValueError("Problème de convergence")
+
             # n impaire dépassement positif
             # n paire dépassement négatif
             if n % 2 == 0:
@@ -746,8 +748,12 @@ entre 0 et 100 %")
             intervalle = 10/w0  # OK pour 5 % et 1 %
             if p < 0.01:
                 # on élargie l'intervalle
+                compteur = 0
                 while u(intervalle) < 1-p:
                     intervalle *= 2
+                    compteur += 1
+                    if compteur > 10000:
+                        raise ValueError("Problème de convergence")
             return _rechercheSolution(0, intervalle, 1-p, 1e-9, u)
 
         elif m > 1:
@@ -756,7 +762,8 @@ entre 0 et 100 %")
 
             def u(t):
                 # réponse indicielle unitaire
-                return 1-(0.5/m0)*(math.exp(-w0*(m-m0)*t)/(m-m0)-math.exp(-w0*(m+m0)*t)/(m+m0))
+                return (1-(0.5/m0)*(math.exp(-w0*(m-m0)*t)/(m-m0)
+                        - math.exp(-w0*(m+m0)*t)/(m+m0)))
             # recherche solution
             # solution tr 5 % # 4.74/w0 pour m=1
             # solution tr 1 % # 6.64/w0 pour m=1
@@ -771,8 +778,12 @@ entre 0 et 100 %")
             intervalle = m*10/w0  # OK pour 5 % et 1 %
             if p < 0.01:
                 # on élargie l'intervalle
+                compteur = 0
                 while u(intervalle) < 1-p:
                     intervalle *= 2
+                    compteur += 1
+                    if compteur > 10000:
+                        raise ValueError("Problème de convergence")
             return _rechercheSolution(0, intervalle, 1-p, 1e-9, u)
 
     @staticmethod
@@ -791,12 +802,9 @@ Exemple :
             elif depassement == 100:
                 return 0
             else:
-                # résolution à partir de la fonction inverse
-                # return _rechercheSolution(0, 1, depassement, 1e-9,
-                #                           Ordre2.abaque_depassement)
-
-                # solution exacte !
-                return -math.log(depassement/100)/math.sqrt(math.pi**2+math.log(depassement/100)**2)
+                # formule théorique
+                return (-math.log(depassement/100)/math.sqrt(math.pi**2
+                        + math.log(depassement/100)**2))
         raise ValueError("Le premier dépassement doit être compris \
 entre 0 et 100 %")
 
@@ -813,7 +821,7 @@ Exemple :
         if 0 <= coeff_amortissement <= 1:
             if coeff_amortissement == 1:
                 return 0
-            # formule exacte
+            # formule théorique
             D = math.exp(-n*coeff_amortissement*math.pi /
                          (math.sqrt(1-coeff_amortissement**2)))*100
             return D
@@ -1047,7 +1055,7 @@ Exemple :
         else:
             a = c
         compteur += 1
-        if compteur > 1000:
+        if compteur > 10000:
             raise ValueError("Problème de convergence")
     return c
 
